@@ -10,8 +10,8 @@ require 'delegate'
 
 class Reserver < Delegator
   WakeUp = Class.new(Timeout::Error)
-  Add = Struct.new(:reserver)
-  Delete = Struct.new(:reserver)
+  Add = Data.define(:reserver)
+  Delete = Data.define(:reserver)
   @queue = Thread::Queue.new
 
   attr_reader :time, :thread_class
