@@ -37,7 +37,7 @@ module Gtk
     def build!(widget, optional, menu = temporary_menu)
       @contextmenu.each do |param|
         label, cond, proc, icon = param
-        if cond.call(*[optional, widget][0, (cond.arity == -1 ? 1 : cond.arity)])
+        if cond.call(*[optional, widget][0, (cond.arity < 0 ? 1 : cond.arity)])
           if label
             item = gen_menu_item(label_text(label, optional, widget), icon, optional, widget)
             if proc
@@ -78,11 +78,12 @@ module Gtk
         icon = icon.call(*[optional, widget][0, (icon.arity == -1 ? 1 : icon.arity)])
       end
       if icon
-        Gtk::ImageMenuItem.new(label_text).tap do |item|
+        Gtk::ImageMenuItem.new(label: label_text, use_underline: false).tap do |item|
           item.set_image(Gtk::WebIcon.new(icon, 16, 16))
+          item.always_show_image = true
         end
       else
-        Gtk::MenuItem.new(label_text)
+        Gtk::MenuItem.new(label: label_text, use_underline: false)
       end
     end
   end
