@@ -1,10 +1,10 @@
 #!/bin/sh
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; mode: ruby -*-
 exec ruby -x "$0" "$@"
 #!ruby
 =begin rdoc
 = mikutter - simple, powerful and moeful Mastodon client
-Copyright (C) 2009-2022 Toshiaki Asai
+Copyright (C) 2009-2024 Toshiaki Asai
 
 This software is released under the MIT License.
 
@@ -13,10 +13,9 @@ http://opensource.org/licenses/mit-license.php
 =end
 module Mikutter; end
 
-require_relative 'core/boot/option'
-Mopt.parse exec_command: true
+Regexp.timeout = 1.0
 
-if !ENV['DISABLE_BUNDLER_SETUP'] || ['', '0'].include?(ENV['DISABLE_BUNDLER_SETUP'].to_s)
+if !ENV.fetch('DISABLE_BUNDLER_SETUP', nil) || ['', '0'].include?(ENV.fetch('DISABLE_BUNDLER_SETUP', nil).to_s)
   begin
     ENV['BUNDLE_GEMFILE'] = File.expand_path(File.join(File.dirname($0), "Gemfile"))
     require 'bundler/setup'
@@ -26,14 +25,17 @@ if !ENV['DISABLE_BUNDLER_SETUP'] || ['', '0'].include?(ENV['DISABLE_BUNDLER_SETU
   end
 end
 
+require_relative 'core/miquire'
+require 'boot/delayer'
+require 'boot/option'
+Mopt.parse exec_command: true
+
 ENV['LIBOVERLAY_SCROLLBAR'] = '0'
 
 require 'benchmark'
 require 'thread'
 require 'fileutils'
 
-require_relative 'core/miquire'
-
 require 'lib/diva_hacks'
 require 'lib/lazy'
 require 'lib/reserver'
@@ -45,7 +47,6 @@ require_relative 'core/utils'
 
 require 'boot/check_config_permission'
 require 'boot/mainloop'
-require 'boot/delayer'
 require 'environment'
 
 Dir.chdir(Environment::CONFROOT)
@@ -60,6 +61,7 @@ Plugin.call(:boot, nil)
 # _profile_ がtrueなら、プロファイリングした結果を一時ディレクトリに保存する
 def boot!(profile)
   begin
+    RubyVM::YJIT.enable if RUBY_VERSION.split('.') >= %w[3 3]
     if profile
       require 'ruby-prof'
       begin
@@ -111,7 +113,10 @@ begin
     $stderr = File.open(errfile, 'w')
     def $stderr.write(string)
       super(string)
-      self.fsync rescue nil end end
+      self.fsync rescue nil
+    end
+    $logger = nil # 次の呼び出しから Kernel.logger の出力先が新しい stderr になるようにする
+  end
   boot!(Mopt.profile)
   if(Delayer.exception)
     raise Delayer.exception end
