@@ -1,13 +1,13 @@
 # frozen_string_literal: true
 
 class Plugin::ExtractGtk::DatasourceSelectBox < Gtk::HierarchycalSelectBox
-  def initialize(sources, &block)
-    super(datasources, sources, &block)
+  def initialize(sources, &)
+    super(datasources, sources, &)
   end
 
   def datasources
     (Plugin.filtering(:extract_datasources, {}) || [{}]).first.map do |id, source_name|
-      [id, source_name.is_a?(String) ? source_name.split('/'.freeze) : source_name]
+      [id, source_name.is_a?(String) ? source_name.split('/') : source_name]
     end
   end
 
@@ -29,19 +29,19 @@ class Plugin::ExtractGtk::DatasourceSelectBox < Gtk::HierarchycalSelectBox
 
   def copy_subscriber(datasource)
     ->(_optional=nil, _widget=nil) do
-      Gtk::Clipboard.copy(<<~'EOM' % {ds: datasource.to_sym.inspect})
-      subscribe(:extract_receive_message, %{ds}).each do |message|
-        
-      end
-      EOM
+      Gtk::Clipboard.copy(<<~CODE % { ds: datasource.to_sym.inspect })
+        subscribe(:extract_receive_message, %{ds}).each do |message|
+        #{'  '}
+        end
+      CODE
     end
   end
 
   private
 
   def selected_datasource_names
-    self.selection.to_enum(:selected_each).map {|_, _, iter|
+    selection.to_enum(:selected_each).map do |_, _, iter|
       iter[ITER_ID]
-    }
+    end
   end
 end
