@@ -9,7 +9,7 @@ module Plugin::Gtk3
     end
 
     def set_button
-      self.children.each(&method(:remove))
+      children.each(&method(:remove))
       current_world, = Plugin.filtering(:world_current, nil)
       ToolbarGenerator.generate(
         self,
@@ -19,7 +19,8 @@ module Plugin::Gtk3
           messages: [],
           world: current_world
         ),
-        :tab)
+        :tab
+      )
     end
   end
 end
