@@ -61,6 +61,28 @@ Plugin.create(:mastodon) do
     }
   end
 
+  command(:mastodon_pin_message, name: _('ブックマークする'), visible: true, role: :timeline,
+          condition: lambda { |opt|
+            opt.messages.any? { |m| bookmark_message?(opt.world, m) }
+          }) do |opt|
+    opt.messages.select{ |m|
+      bookmark_message?(opt.world, m)
+    }.each { |status|
+      opt.world.bookmark(status)
+    }
+  end
+
+  command(:mastodon_unpin_message, name: _('ブックマークを解除する'), visible: true, role: :timeline,
+          condition: lambda { |opt|
+            opt.messages.any? { |m| unbookmark_message?(opt.world, m) }
+          }) do |opt|
+    opt.messages.select{ |m|
+      unbookmark_message?(opt.world, m)
+    }.each { |status|
+      opt.world.unbookmark(status)
+    }
+  end
+
   command(:mastodon_edit_list_membership, name: _('リストへの追加・削除'), visible: true, role: :timeline,
           condition: lambda { |opt|
             mastodon?(opt.world)
@@ -470,6 +492,18 @@ Plugin.create(:mastodon) do
     world.unpin(status)
   end
 
+  defspell(:bookmark_message, :mastodon, :mastodon_status,
+           condition: -> (world, status) { !status.bookmarked? }
+          ) do |world, status|
+    world.bookmark(status)
+  end
+
+  defspell(:unbookmark_message, :mastodon, :mastodon_status,
+           condition: -> (world, status) { status.bookmarked? }
+          ) do |world, status|
+    world.unbookmark(status)
+  end
+
   defspell(:mastodon, :mastodon) do |mastodon|
     true
   end
