@@ -3,10 +3,10 @@ module Plugin::MastodonSetting
     include Gtk::TreeViewPrettyScroll
     COL_DOMAIN = 0
 
-    def initialize()
+    def initialize
       super()
       set_model(::Gtk::ListStore.new(String))
-      append_column ::Gtk::TreeViewColumn.new("ドメイン名", ::Gtk::CellRendererText.new, text: COL_DOMAIN)
+      append_column ::Gtk::TreeViewColumn.new('ドメイン名', ::Gtk::CellRendererText.new, text: COL_DOMAIN)
 
       Plugin::Mastodon::Instance.domains.each(&method(:add_record))
     end
@@ -23,7 +23,7 @@ module Plugin::MastodonSetting
     end
 
     def remove_record(domain)
-      remove_iter = model.to_enum(:each).map{|_,_,iter| iter }.find{|iter| domain == iter[COL_DOMAIN] }
+      remove_iter = model.to_enum(:each).map { |_, _, iter| iter }.find { |iter| domain == iter[COL_DOMAIN] }
       model.remove(remove_iter) if remove_iter
       self
     end
