@@ -17,7 +17,7 @@ module Plugin::MastodonSseStreaming
 
     def headers
       if token
-        { 'Authorization' => 'Bearer %{token}' % { token: token } }
+        { 'Authorization' => 'Bearer %{token}' % { token: } }
       else
         {}
       end
@@ -29,17 +29,16 @@ module Plugin::MastodonSseStreaming
         client = HTTPClient.new
         client.ssl_config.set_default_paths
         notice "connect #{@connection_type.perma_link} (#{@connection_type})"
-        response = client.request(:get, @connection_type.perma_link.to_s, {}, {}, headers) do |fragment|
-          yielder << fragment
-        end
-        if response
-          raise ResponseError.new(
-            response.reason,
-            code: response.status_code,
-            response: response
-          )
-        else
-          raise ConnectionRefusedError
+        client.request(:get, @connection_type.perma_link.to_s, {}, {}, headers) do |response, part|
+          if response.ok?
+            yielder << part
+          else
+            raise ResponseError.new(
+              response.reason,
+              code: response.status_code,
+              response:
+            )
+          end
         end
       rescue SocketError,
              HTTPClient::BadResponseError,
