@@ -12,10 +12,10 @@ Plugin.create(:openimg_gtk) do
   UserConfig[:openimg_window_size_height_percent] ||= 70
   UserConfig[:openimg_window_size_reference] ||= :mainwindow
   UserConfig[:openimg_window_size_reference_manual_num] ||= 0
-  
-  filter_openimg_pixbuf_from_display_url do |photo, loader, thread|
+
+  filter_openimg_pixbuf_from_display_url do |photo, _, _|
     loader = GdkPixbuf::PixbufLoader.new
-    [photo, loader, photo.download{|partial| loader.write partial }]
+    [photo, loader, photo.download { |partial| loader.write partial }]
   end
 
   intent Plugin::Openimg::Photo do |intent_token|
